print.Rcpp_tlars_cpp: Prints a summary of the results stored in a C++ object of...

View source: R/print.Rcpp_tlars_cpp.R

print.Rcpp_tlars_cppR Documentation

Prints a summary of the results stored in a C++ object of class tlars_cpp.

Description

Prints a summary of the results stored in a C++ object of class tlars_cpp (see tlars_cpp for details), i.e., selected variables, computation time, and number of included dummies.

Usage

## S3 method for class 'Rcpp_tlars_cpp'
print(x, ...)

Arguments

x

Object of the class tlars_cpp. See tlars_cpp for details.

...

Ignored. Only added to keep structure of generic print function.

Value

Prints a summary of the results stored in a C++ object of class tlars_cpp.

See Also

tlars_cpp.

Examples

data("Gauss_data")
X <- Gauss_data$X
y <- drop(Gauss_data$y)
p <- ncol(X)
n <- nrow(X)
num_dummies <- p
dummies <- matrix(stats::rnorm(n * p), nrow = n, ncol = num_dummies)
XD <- cbind(X, dummies)
mod_tlars <- tlars_model(X = XD, y = y, num_dummies = num_dummies)
tlars(model = mod_tlars, T_stop = 3, early_stop = TRUE)
print(mod_tlars)

tlars documentation built on June 22, 2024, 11:46 a.m.